.. _Intro:

ndpyramid
---------

A small utility for generating ND array pyramids using Xarray and Zarr.

.. toctree::
    :maxdepth: 1
    :hidden:
    :caption: Getting Started

    Quickstart <quick-start>

.. toctree::
    :maxdepth: 1
    :hidden:
    :caption: Usage

    Generating Pyramids <generate-pyramids>


.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Reference

    API <api>
    schema
